#
# spec file for package python-pivy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pivy
Version:        0.6.5
Release:        lp152.2.2
Summary:        Coin Binding for Python
License:        ISC AND GPL-2.0-or-later
Group:          Development/Libraries/Python
URL:            https://github.com/FreeCAD/pivy
Source0:        https://github.com/FreeCAD/pivy/archive/%{version}.tar.gz#/pivy-%{version}.tar.gz
# PATCH-FIX-OPENSUSE 0001-Allow-using-SoQt-snapshots-with-stable-Coin-version.patch -- Use CMake to find Coin and SoQt
Patch1:         0001-Allow-using-SoQt-snapshots-with-stable-Coin-version.patch
# PATCH-FIX-OPENSUSE 0002-Fix-the-qmake-executable-name.patch -- Fix the qmake executable name
Patch2:         0002-Fix-the-qmake-executable-name.patch
BuildRequires:  %{python_module devel}
BuildRequires:  Coin-devel
BuildRequires:  SoQt-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  python-rpm-macros
BuildRequires:  swig
%python_subpackages

%description
Pivy is a Coin binding for Python. Coin is a high-level 3D graphics library
with a C++ Application Programming Interface. Coin uses scene-graph data
structures to render real-time graphics suitable for mostly all kinds of
scientific and engineering visualization applications.

Pivy allows:

- Development of Coin applications and extensions in Python
- Interactive modification of Coin programs from within the Python interpreter
  at runtime
- Incorporation of Scripting Nodes into the scene graph which are capable of
  executing Python code and callbacks

%prep
%autosetup -p1 -n pivy-%{version}

%build
export CFLAGS="%{optflags}"
%{python_build ; rm pivy/coin_wrap.cpp pivy/gui/soqt_wrap.cpp }

%install
%python_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}/pivy/

%files %{python_files}
%license LICENSE
%doc AUTHORS HACKING NEWS README.md THANKS
%{python_sitelib}/pivy/
%{python_sitelib}/Pivy-%{version}-py%{python_version}.egg-info

%changelog
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Use correct macro %%{python_version} instead of %%{py_ver} to
  pack egg-info file.
- Drop macro definitions needed for obsolete openSUSE versions.
* Sat Mar 14 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to 0.6.5
  - Unifying release for merge of FreeCAD/pivy and
    bitbucket.org/coin3d/pivy repos
  - change pivy.graphics API to follow pep8 naming scheme
    suggestion.
  - workaround for beveled text
  - swig4.0 fix
  - update to latest coin (additional fakeheaders)
  - example Complex3dText: add license and shebang
    this was unintentional removed at some point
- Remove Fix-issue-39-PyUnicode_AsUTF8-returns-const-char.patch
  applied upstream
- 0001-Allow-using-SoQt-snapshots-with-stable-Coin-version.patch
  adjusted
* Mon May 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Allow-using-SoQt-snapshots-with-stable-Coin-version.patch
  This will allow using SoQt snapshots with stable Coin releases.
- Add 0002-Fix-the-qmake-executable-name.patch. The qmake executable
  is called qmake-qt5 for openSUSE.
- Run spec-cleaner
* Mon Feb  4 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add Fix-issue-39-PyUnicode_AsUTF8-returns-const-char.patch to fix
  build in Factory
* Tue Oct  9 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 0.6.3
  * qt5-support (qt4 not supported anymore)
- Update to 0.6.4
  * bool(coin.SoGroup) -> True (also if group is empty) [same behaviour as py2]
  * add graphics arrow object
  * making it possible to compile with older coin version (without cmake) -> setup_old.py
  * adding back qt4 compatibility (but tests are still qt5 depenent)
  * added pivy.version
  * some fixes
- %%python_expand call to fdupes
* Wed Jan  3 2018 dev@stellardeath.org
- Fix build failure when using more than one python version:
  swig wrapper files were only generated the first time and
  and then kept for subsequent builds.
* Sat Dec 16 2017 badshah400@gmail.com
- Convert specfile to python-singlespec: fixes build failures in
  Factory. Doesn't build against python2 for unknown reasons, so
  turn off python2 modules until this is fixed.
- Use fdupes (added to BuildRequires) to link duplicate files.
* Thu Sep 14 2017 kkaempf@suse.com
- update to 0.6.2
  * builds for python3 (linux: 3.4, 3.5, 3.6; win: 3.5, 3.6)
    or python2 (2.7)
  * uses pyside instead of pyqt for soqt4 bindings
  * has many fixes (especially for FreeCAD)
- switch to github.com/FreeCAD/pivy, coin3d.org is dead
* Sat May  5 2012 asterios.dramis@gmail.com
- Initial release (version 0.5.0hg.609).
